import { getEnv } from "@hugoalh/env/env";
import { isJSONPrimitive, } from "@hugoalh/is-json";
import { isStringSingleLine } from "@hugoalh/is-string-singleline";
import { stringifyInput } from "./_share.js";
import { appendFileMapCommand, clearFileCommand, optimizeFileCommand } from "./command/file.js";
/**
 * **\[🅰️ Advanced\]** Clear the outputs which set in the current step.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - `GITHUB_OUTPUT`
 * > - File System - Read \[Deno: `read`; NodeJS (>= v20.9.0) 🧪: `fs-read`\]
 * >   - *Resources*
 * > - File System - Write \[Deno: `write`; NodeJS (>= v20.9.0) 🧪: `fs-write`\]
 * >   - *Resources*
 * @returns {void}
 */
export function clearOutput() {
    return clearFileCommand("GITHUB_OUTPUT");
}
/**
 * **\[🅰️ Advanced\]** Clear the states which set in the current step.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - `GITHUB_STATE`
 * > - File System - Read \[Deno: `read`; NodeJS (>= v20.9.0) 🧪: `fs-read`\]
 * >   - *Resources*
 * > - File System - Write \[Deno: `write`; NodeJS (>= v20.9.0) 🧪: `fs-write`\]
 * >   - *Resources*
 * @returns {void}
 */
export function clearState() {
    return clearFileCommand("GITHUB_STATE");
}
/**
 * Get the raw value of a parameter.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - *Resources*
 * @param {string} source Source of the parameter.
 * @param {string} key Key of the parameter.
 * @returns {string} Raw value of the parameter.
 */
function getParameter(source, key) {
    if (!isStringSingleLine(key)) {
        throw new SyntaxError(`\`${key}\` is not a valid GitHub Actions ${source.toLowerCase()} key!`);
    }
    return getEnv(`${source.toUpperCase()}_${key.replaceAll(" ", "_").toUpperCase()}`) ?? "";
}
export function getInput(key, options = {}) {
    const { fallback = true, require = false } = options;
    const value = getParameter("Input", key);
    if (value.length === 0) {
        if (require) {
            throw new ReferenceError(`Input \`${key}\` is not defined!`);
        }
        return (fallback ? "" : undefined);
    }
    return value;
}
export { getInput as getInputString };
export function getInputBigInt(key, options = {}) {
    const { fallback = true, require = false } = options;
    const value = getParameter("Input", key);
    if (value.length === 0) {
        if (require) {
            throw new ReferenceError(`Input \`${key}\` is not defined!`);
        }
        return (fallback ? 0n : undefined);
    }
    try {
        return BigInt(value.replace(/n$/, ""));
    }
    catch {
        throw new SyntaxError(`Input \`${key}\` is not a valid big integer!`);
    }
}
export { getInputBigInt as getInputBigInteger };
export function getInputBoolean(key, options = {}) {
    const { fallback = true, require = false } = options;
    const value = getParameter("Input", key);
    if (value.length === 0) {
        if (require) {
            throw new ReferenceError(`Input \`${key}\` is not defined!`);
        }
        return (fallback ? false : undefined);
    }
    switch (value) {
        case "false":
        case "False":
        case "FALSE":
            return false;
        case "true":
        case "True":
        case "TRUE":
            return true;
        default:
            throw new SyntaxError(`Input \`${key}\` is not a valid boolean!`);
    }
}
export function getInputJSON(key, options = {}) {
    const { fallback = true, require = false } = options;
    const value = getParameter("Input", key);
    if (value.length === 0) {
        if (require) {
            throw new ReferenceError(`Input \`${key}\` is not defined!`);
        }
        return (fallback ? null : undefined);
    }
    try {
        return JSON.parse(value);
    }
    catch {
        throw new SyntaxError(`Input \`${key}\` is not a valid JSON value!`);
    }
}
export { getInputJSON as getInputJSONValue };
export function getInputJSONArray(key, options = {}) {
    const { fallback = true, require = false } = options;
    const value = getInputJSON(key, {
        fallback: false,
        require: false
    });
    if (typeof value === "undefined") {
        if (require) {
            throw new ReferenceError(`Input \`${key}\` is not defined!`);
        }
        return (fallback ? [] : undefined);
    }
    if (!Array.isArray(value)) {
        throw new SyntaxError(`Input \`${key}\` is not a valid JSON array!`);
    }
    return value;
}
export function getInputJSONObject(key, options = {}) {
    const { fallback = true, require = false } = options;
    const value = getInputJSON(key, {
        fallback: false,
        require: false
    });
    if (typeof value === "undefined") {
        if (require) {
            throw new ReferenceError(`Input \`${key}\` is not defined!`);
        }
        return (fallback ? {} : undefined);
    }
    if (!(typeof value === "object" && !Array.isArray(value) && value !== null)) {
        throw new SyntaxError(`Input \`${key}\` is not a valid JSON object!`);
    }
    return value;
}
export function getInputJSONPrimitive(key, options = {}) {
    const { fallback = true, require = false } = options;
    const value = getInputJSON(key, {
        fallback: false,
        require: false
    });
    if (typeof value === "undefined") {
        if (require) {
            throw new ReferenceError(`Input \`${key}\` is not defined!`);
        }
        return (fallback ? null : undefined);
    }
    if (!isJSONPrimitive(value)) {
        throw new SyntaxError(`Input \`${key}\` is not a valid JSON primitive!`);
    }
    return value;
}
export function getInputNumber(key, options = {}) {
    const { fallback = true, require = false } = options;
    const value = getParameter("Input", key);
    if (value.length === 0) {
        if (require) {
            throw new ReferenceError(`Input \`${key}\` is not defined!`);
        }
        return (fallback ? 0 : undefined);
    }
    try {
        return Number(value);
    }
    catch {
        throw new SyntaxError(`Input \`${key}\` is not a valid number!`);
    }
}
export function getState(key, options = {}) {
    const { fallback = true, require = false } = options;
    const value = getParameter("State", key);
    if (value.length === 0) {
        if (require) {
            throw new ReferenceError(`State \`${key}\` is not defined!`);
        }
        return (fallback ? "" : undefined);
    }
    return value;
}
export { getState as getStateString };
export function getStateBigInt(key, options = {}) {
    const { fallback = true, require = false } = options;
    const value = getParameter("State", key);
    if (value.length === 0) {
        if (require) {
            throw new ReferenceError(`State \`${key}\` is not defined!`);
        }
        return (fallback ? 0n : undefined);
    }
    try {
        return BigInt(value.replace(/n$/, ""));
    }
    catch {
        throw new SyntaxError(`State \`${key}\` is not a valid big integer!`);
    }
}
export { getStateBigInt as getStateBigInteger };
export function getStateBoolean(key, options = {}) {
    const { fallback = true, require = false } = options;
    const value = getParameter("State", key);
    if (value.length === 0) {
        if (require) {
            throw new ReferenceError(`State \`${key}\` is not defined!`);
        }
        return (fallback ? false : undefined);
    }
    switch (value) {
        case "false":
        case "False":
        case "FALSE":
            return false;
        case "true":
        case "True":
        case "TRUE":
            return true;
        default:
            throw new SyntaxError(`State \`${key}\` is not a valid boolean!`);
    }
}
export function getStateJSON(key, options = {}) {
    const { fallback = true, require = false } = options;
    const value = getParameter("State", key);
    if (value.length === 0) {
        if (require) {
            throw new ReferenceError(`State \`${key}\` is not defined!`);
        }
        return (fallback ? null : undefined);
    }
    try {
        return JSON.parse(value);
    }
    catch {
        throw new SyntaxError(`State \`${key}\` is not a valid JSON value!`);
    }
}
export { getStateJSON as getStateJSONValue };
export function getStateJSONArray(key, options = {}) {
    const { fallback = true, require = false } = options;
    const value = getStateJSON(key, {
        fallback: false,
        require: false
    });
    if (typeof value === "undefined") {
        if (require) {
            throw new ReferenceError(`State \`${key}\` is not defined!`);
        }
        return (fallback ? [] : undefined);
    }
    if (!Array.isArray(value)) {
        throw new SyntaxError(`State \`${key}\` is not a valid JSON array!`);
    }
    return value;
}
export function getStateJSONObject(key, options = {}) {
    const { fallback = true, require = false } = options;
    const value = getStateJSON(key, {
        fallback: false,
        require: false
    });
    if (typeof value === "undefined") {
        if (require) {
            throw new ReferenceError(`State \`${key}\` is not defined!`);
        }
        return (fallback ? {} : undefined);
    }
    if (!(typeof value === "object" && !Array.isArray(value) && value !== null)) {
        throw new SyntaxError(`State \`${key}\` is not a valid JSON object!`);
    }
    return value;
}
export function getStateJSONPrimitive(key, options = {}) {
    const { fallback = true, require = false } = options;
    const value = getStateJSON(key, {
        fallback: false,
        require: false
    });
    if (typeof value === "undefined") {
        if (require) {
            throw new ReferenceError(`State \`${key}\` is not defined!`);
        }
        return (fallback ? null : undefined);
    }
    if (!isJSONPrimitive(value)) {
        throw new SyntaxError(`State \`${key}\` is not a valid JSON primitive!`);
    }
    return value;
}
export function getStateNumber(key, options = {}) {
    const { fallback = true, require = false } = options;
    const value = getParameter("State", key);
    if (value.length === 0) {
        if (require) {
            throw new ReferenceError(`State \`${key}\` is not defined!`);
        }
        return (fallback ? 0 : undefined);
    }
    try {
        return Number(value);
    }
    catch {
        throw new SyntaxError(`State \`${key}\` is not a valid number!`);
    }
}
/**
 * **\[🅰️ Advanced\]** Optimize the outputs which set in the current step to reduce size whenever possible.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - `GITHUB_OUTPUT`
 * > - File System - Read \[Deno: `read`; NodeJS (>= v20.9.0) 🧪: `fs-read`\]
 * >   - *Resources*
 * > - File System - Write \[Deno: `write`; NodeJS (>= v20.9.0) 🧪: `fs-write`\]
 * >   - *Resources*
 * @returns {void}
 */
export function optimizeOutput() {
    return optimizeFileCommand("GITHUB_OUTPUT");
}
/**
 * **\[🅰️ Advanced\]** Optimize the states which set in the current step to reduce size whenever possible.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - `GITHUB_STATE`
 * > - File System - Read \[Deno: `read`; NodeJS (>= v20.9.0) 🧪: `fs-read`\]
 * >   - *Resources*
 * > - File System - Write \[Deno: `write`; NodeJS (>= v20.9.0) 🧪: `fs-write`\]
 * >   - *Resources*
 * @returns {void}
 */
export function optimizeState() {
    return optimizeFileCommand("GITHUB_STATE");
}
export function setOutput(param0, param1) {
    const pairs = new Map();
    if (typeof param0 === "string") {
        if (!isStringSingleLine(param0)) {
            throw new SyntaxError(`\`${param0}\` is not a valid GitHub Actions output key!`);
        }
        pairs.set(param0, stringifyInput(param1));
    }
    else {
        for (const [key, value] of ((param0 instanceof Map) ? param0.entries() : Object.entries(param0))) {
            if (!isStringSingleLine(key)) {
                throw new SyntaxError(`\`${key}\` is not a valid GitHub Actions output key!`);
            }
            pairs.set(key, stringifyInput(value));
        }
    }
    if (pairs.size > 0) {
        appendFileMapCommand("GITHUB_OUTPUT", pairs);
    }
}
export function setState(param0, param1) {
    const pairs = new Map();
    if (typeof param0 === "string") {
        if (!isStringSingleLine(param0)) {
            throw new SyntaxError(`\`${param0}\` is not a valid GitHub Actions state key!`);
        }
        pairs.set(param0, stringifyInput(param1));
    }
    else {
        for (const [key, value] of ((param0 instanceof Map) ? param0.entries() : Object.entries(param0))) {
            if (!isStringSingleLine(key)) {
                throw new SyntaxError(`\`${key}\` is not a valid GitHub Actions state key!`);
            }
            pairs.set(key, stringifyInput(value));
        }
    }
    if (pairs.size > 0) {
        appendFileMapCommand("GITHUB_STATE", pairs);
    }
}
