import * as dntShim from "./_dnt.shims.js";
/**
 * GitHub Actions runner architecture.
 */
export type GitHubActionsRunnerArchitecture = "ARM" | "ARM64" | "X64" | "X86";
/**
 * Get the architecture of the GitHub Actions runner.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - `RUNNER_ARCH`
 * @returns {GitHubActionsRunnerArchitecture} Architecture of the GitHub Actions runner.
 * @example
 * ```ts
 * getRunnerArchitecture();
 * //=> "X64"
 * ```
 */
export declare function getRunnerArchitecture(): GitHubActionsRunnerArchitecture;
export { getRunnerArchitecture as getRunnerArch };
/**
 * Get the debug status of the GitHub Actions runner.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - `RUNNER_DEBUG`
 * @returns {boolean} Debug status of the GitHub Actions runner.
 */
export declare function getRunnerDebugStatus(): boolean;
export { getRunnerDebugStatus as isRunnerDebug };
/**
 * Get the name of the GitHub Actions runner.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - `RUNNER_NAME`
 * @returns {string} Name of the GitHub Actions runner.
 * @example
 * ```ts
 * getRunnerName();
 * //=> "Hosted Agent"
 * ```
 */
export declare function getRunnerName(): string;
/**
 * GitHub Actions runner OS.
 */
export type GitHubActionsRunnerOS = "Linux" | "macOS" | "Windows";
/**
 * Get the OS of the GitHub Actions runner.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - `RUNNER_OS`
 * @returns {GitHubActionsRunnerOS} OS of the GitHub Actions runner.
 * @example
 * ```ts
 * getRunnerOS();
 * //=> "Windows"
 * ```
 */
export declare function getRunnerOS(): GitHubActionsRunnerOS;
/**
 * Get the absolute path of the `TEMP` directory of the GitHub Actions runner.
 *
 * `TEMP` directory is emptied at the beginning and end of each job, files will not be removed if the runner's user account does not have permission to delete them.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - `RUNNER_TEMP`
 * @returns {string} Absolute path of the `TEMP` directory of the GitHub Actions runner.
 * @example
 * ```ts
 * getRunnerTempPath();
 * //=> "D:\\a\\_temp"
 * ```
 */
export declare function getRunnerTempPath(): string;
/**
 * Get the absolute path of the tool cache directory of the GitHub hosted GitHub Actions runner.
 *
 * For self hosted GitHub Actions runner, the tool cache directory may not exist and will return `undefined`.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - `RUNNER_TOOL_CACHE`
 * @returns {string | undefined} Absolute path of the tool cache directory of the GitHub hosted GitHub Actions runner.
 * @example
 * ```ts
 * getRunnerToolCachePath();
 * //=> "C:\\hostedtoolcache\\windows"
 * ```
 */
export declare function getRunnerToolCachePath(): string | undefined;
/**
 * Get the absolute path of the workspace of the GitHub Actions runner; The default working directory on the runner for steps.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - `GITHUB_WORKSPACE`
 * @returns {string} Absolute path of the workspace of the GitHub Actions runner.
 * @example
 * ```ts
 * getRunnerWorkspacePath();
 * //=> "/home/runner/work/my-repo-name/my-repo-name"
 * ```
 */
export declare function getRunnerWorkspacePath(): string;
export interface GitHubActionsRunnerTestOptions {
    /**
     * Also test whether have artifact resources.
     * @default false
     */
    artifact?: boolean;
    /**
     * Also test whether have cache resources.
     * @default false
     */
    cache?: boolean;
    /**
     * Also test whether have OpenID Connect (OIDC) resources.
     * @default false
     */
    oidc?: boolean;
    /**
     * Also test whether have tool cache resources.
     * @default false
     */
    toolCache?: boolean;
}
/**
 * Test the current process whether is executing inside the GitHub Actions runner.
 *
 * If this test is mandatory, use function {@linkcode validateInRunner} instead.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - `ACTIONS_CACHE_URL` (Optional)
 * >   - `ACTIONS_ID_TOKEN_REQUEST_TOKEN` (Optional)
 * >   - `ACTIONS_ID_TOKEN_REQUEST_URL` (Optional)
 * >   - `ACTIONS_RESULTS_URL` (Optional)
 * >   - `ACTIONS_RUNTIME_TOKEN` (Optional)
 * >   - `ACTIONS_RUNTIME_URL` (Optional)
 * >   - `CI`
 * >   - `GITHUB_ACTION`
 * >   - `GITHUB_ACTIONS`
 * >   - `GITHUB_ACTOR`
 * >   - `GITHUB_ACTOR_ID`
 * >   - `GITHUB_API_URL`
 * >   - `GITHUB_ENV`
 * >   - `GITHUB_EVENT_NAME`
 * >   - `GITHUB_EVENT_PATH`
 * >   - `GITHUB_GRAPHQL_URL`
 * >   - `GITHUB_JOB`
 * >   - `GITHUB_OUTPUT`
 * >   - `GITHUB_PATH`
 * >   - `GITHUB_REF_NAME`
 * >   - `GITHUB_REF_TYPE`
 * >   - `GITHUB_REPOSITORY`
 * >   - `GITHUB_REPOSITORY_ID`
 * >   - `GITHUB_REPOSITORY_OWNER`
 * >   - `GITHUB_REPOSITORY_OWNER_ID`
 * >   - `GITHUB_RETENTION_DAYS`
 * >   - `GITHUB_RUN_ATTEMPT`
 * >   - `GITHUB_RUN_ID`
 * >   - `GITHUB_RUN_NUMBER`
 * >   - `GITHUB_SERVER_URL`
 * >   - `GITHUB_SHA`
 * >   - `GITHUB_STATE`
 * >   - `GITHUB_STEP_SUMMARY`
 * >   - `GITHUB_WORKFLOW`
 * >   - `GITHUB_WORKFLOW_REF`
 * >   - `GITHUB_WORKFLOW_SHA`
 * >   - `GITHUB_WORKSPACE`
 * >   - `RUNNER_ARCH`
 * >   - `RUNNER_NAME`
 * >   - `RUNNER_OS`
 * >   - `RUNNER_TEMP`
 * >   - `RUNNER_TOOL_CACHE` (Optional)
 * @param {GitHubActionsRunnerTestOptions} [options={}] Options.
 * @returns {boolean} Test result.
 */
export declare function isInRunner(options?: GitHubActionsRunnerTestOptions): boolean;
/**
 * Validate the current process whether is executing inside the GitHub Actions runner.
 *
 * If this test is optional, use function {@linkcode isInRunner} instead.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - `ACTIONS_CACHE_URL` (Optional)
 * >   - `ACTIONS_ID_TOKEN_REQUEST_TOKEN` (Optional)
 * >   - `ACTIONS_ID_TOKEN_REQUEST_URL` (Optional)
 * >   - `ACTIONS_RESULTS_URL` (Optional)
 * >   - `ACTIONS_RUNTIME_TOKEN` (Optional)
 * >   - `ACTIONS_RUNTIME_URL` (Optional)
 * >   - `CI`
 * >   - `GITHUB_ACTION`
 * >   - `GITHUB_ACTIONS`
 * >   - `GITHUB_ACTOR`
 * >   - `GITHUB_ACTOR_ID`
 * >   - `GITHUB_API_URL`
 * >   - `GITHUB_ENV`
 * >   - `GITHUB_EVENT_NAME`
 * >   - `GITHUB_EVENT_PATH`
 * >   - `GITHUB_GRAPHQL_URL`
 * >   - `GITHUB_JOB`
 * >   - `GITHUB_OUTPUT`
 * >   - `GITHUB_PATH`
 * >   - `GITHUB_REF_NAME`
 * >   - `GITHUB_REF_TYPE`
 * >   - `GITHUB_REPOSITORY`
 * >   - `GITHUB_REPOSITORY_ID`
 * >   - `GITHUB_REPOSITORY_OWNER`
 * >   - `GITHUB_REPOSITORY_OWNER_ID`
 * >   - `GITHUB_RETENTION_DAYS`
 * >   - `GITHUB_RUN_ATTEMPT`
 * >   - `GITHUB_RUN_ID`
 * >   - `GITHUB_RUN_NUMBER`
 * >   - `GITHUB_SERVER_URL`
 * >   - `GITHUB_SHA`
 * >   - `GITHUB_STATE`
 * >   - `GITHUB_STEP_SUMMARY`
 * >   - `GITHUB_WORKFLOW`
 * >   - `GITHUB_WORKFLOW_REF`
 * >   - `GITHUB_WORKFLOW_SHA`
 * >   - `GITHUB_WORKSPACE`
 * >   - `RUNNER_ARCH`
 * >   - `RUNNER_NAME`
 * >   - `RUNNER_OS`
 * >   - `RUNNER_TEMP`
 * >   - `RUNNER_TOOL_CACHE` (Optional)
 * @param {GitHubActionsRunnerTestOptions} [options={}] Options.
 * @returns {void}
 */
export declare function validateInRunner(options?: GitHubActionsRunnerTestOptions): void;
/**
 * Clear the `TEMP` directory of the GitHub Actions runner.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - `RUNNER_TEMP`
 * > - File System - Read \[Deno: `read`; NodeJS (>= v20.9.0) 🧪: `fs-read`\]
 * >   - *Resources*
 * > - File System - Write \[Deno: `write`; NodeJS (>= v20.9.0) 🧪: `fs-write`\]
 * >   - *Resources*
 * @returns {void}
 */
export declare function clearRunnerTemp(): void;
/**
 * Create/Make a new temporary directory in the `TEMP` directory of the GitHub Actions runner, optionally include prefixing and suffixing the directory name with {@linkcode Deno.MakeTempOptions.prefix} and {@linkcode Deno.MakeTempOptions.suffix} respectively.
 *
 * Multiple programs calling this function simultaneously will create different directories. It is the caller's responsibility to remove the directory when no longer needed.
 *
 * `TEMP` directory is emptied at the beginning and end of each job, files will not be removed if the runner's user account does not have permission to delete them.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - `RUNNER_TEMP`
 * > - File System - Read \[Deno: `read`; NodeJS (>= v20.9.0) 🧪: `fs-read`\]
 * >   - *Resources*
 * > - File System - Write \[Deno: `write`; NodeJS (>= v20.9.0) 🧪: `fs-write`\]
 * >   - *Resources*
 * @returns {string} Absolute path of the new temporary directory in the `TEMP` directory.
 */
export declare function makeRunnerTempDir(options?: Omit<dntShim.Deno.MakeTempOptions, "dir">): string;
export { makeRunnerTempDir as createRunnerTempDir, makeRunnerTempDir as createRunnerTempDirectory, makeRunnerTempDir as makeRunnerTempDirectory };
/**
 * Create/Make a new temporary file in the `TEMP` directory of the GitHub Actions runner, optionally include prefixing and suffixing the file name with {@linkcode Deno.MakeTempOptions.prefix} and {@linkcode Deno.MakeTempOptions.suffix} respectively.
 *
 * Multiple programs calling this function simultaneously will create different files. It is the caller's responsibility to remove the file when no longer needed.
 *
 * `TEMP` directory is emptied at the beginning and end of each job, files will not be removed if the runner's user account does not have permission to delete them.
 *
 * > **🛡️ Runtime Permissions**
 * >
 * > - Environment Variable \[Deno: `env`\]
 * >   - `RUNNER_TEMP`
 * > - File System - Read \[Deno: `read`; NodeJS (>= v20.9.0) 🧪: `fs-read`\]
 * >   - *Resources*
 * > - File System - Write \[Deno: `write`; NodeJS (>= v20.9.0) 🧪: `fs-write`\]
 * >   - *Resources*
 * @returns {string} Absolute path of the new temporary file in the `TEMP` directory.
 */
export declare function makeRunnerTempFile(options?: Omit<dntShim.Deno.MakeTempOptions, "dir">): string;
export { makeRunnerTempFile as createRunnerTempFile };
//# sourceMappingURL=runner.d.ts.map